"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.closeMongoDb = void 0;
const mongodb = require("mongodb");
let client;
let db;
let collection;
const MongoClient = mongodb.MongoClient;
const dbLogger = mongodb.Logger;
dbLogger.setCurrentLogger((_msg, context) => {
    if ((context === null || context === void 0 ? void 0 : context.type) === 'debug') {
        console.debug(context);
    }
    else if ((context === null || context === void 0 ? void 0 : context.type) === 'info') {
        console.info(context);
    }
    else {
        console.error({
            error: new Error(context === null || context === void 0 ? void 0 : context.message),
            extraInfo: {
                logPrefix: `${__filename}[getMongoDb]: `,
                context: context,
            },
        });
    }
});
function getMongoDb(config, cb) {
    if (client) {
        cb(undefined, collection);
    }
    else {
        const logPrefix = `${__filename}[${getMongoDb.name}]: `;
        if (config.logLevel) {
            dbLogger.setLevel(config.logLevel);
        }
        console.debug(`${logPrefix}Connect to ${config.url}`);
        MongoClient.connect(config.url, config.options, (err, newClient) => {
            if (err || !newClient) {
                const error = !newClient
                    ? new Error('No mongo client set.')
                    : err;
                const logErr = {
                    error: error,
                    extraInfo: {
                        function: logPrefix,
                        newClient: newClient,
                        config: config,
                    },
                };
                console.error(logErr);
                cb(err, undefined);
            }
            else {
                client = newClient;
                db = client.db(config.database);
                collection = db.collection(config.collection);
                cb(undefined, collection);
            }
        });
    }
}
exports.default = getMongoDb;
function closeMongoDb(cb) {
    if (client) {
        client.close(() => {
            cb();
        });
    }
    else {
        cb();
    }
}
exports.closeMongoDb = closeMongoDb;
//# sourceMappingURL=getMongoDb.js.map